@@ -1,6 +1,4 @@
-/* -*- mode: c++; c-basic-offset:4 -*-
-    commands/detailscommand.cpp
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2007 Klarälvdalens Datakonsult AB
 
@@ -40,7 +38,10 @@ private:
         }
 
         auto dlg = new CertificateDetailsDialog;
-        applyWindowID(dlg);
+
+        // We're deliberately not setting the parent, since we want the dialog
+        // to be usable independently of the main window.
+        // applyWindowID(dlg);
         dlg->setAttribute(Qt::WA_DeleteOnClose);
         connect(dlg, &QDialog::finished, q_func(), [this](int) {
             slotDialogClosed();
