@@ -1,6 +1,4 @@
-/* -*- mode: c++; c-basic-offset:4 -*-
-    commands/lookupcertificatescommand.cpp
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2008, 2009 Klarälvdalens Datakonsult AB
 
@@ -489,6 +487,7 @@ void LookupCertificatesCommand::Private::tryToFinishKeyLookup()
     }
     if (progress) {
         progress->setValue(progress->maximum());
+        progress->deleteLater();
     }
 
     if (keyListing.result.error() && !keyListing.result.error().isCanceled() && (keyListing.result.error().code() != GPG_ERR_NOT_FOUND)) {
