@@ -1,6 +1,4 @@
 /*
-    appearanceconfigwidget.h
-
     This file is part of kleopatra, the KDE key manager
     SPDX-FileCopyrightText: 2002, 2004, 2008 Klarälvdalens Datakonsult AB
     SPDX-FileCopyrightText: 2002, 2003 Marc Mutz <mutz@kde.org>
@@ -12,7 +10,7 @@
 
 #include <QWidget>
 
-#include <utils/pimpl_ptr.h>
+#include <memory>
 
 namespace Kleo
 {
@@ -35,7 +33,7 @@ Q_SIGNALS:
 
 private:
     class Private;
-    kdtools::pimpl_ptr<Private> d;
+    const std::unique_ptr<Private> d;
     Q_PRIVATE_SLOT(d, void slotIconClicked())
 #ifndef QT_NO_COLORDIALOG
     Q_PRIVATE_SLOT(d, void slotForegroundClicked())
@@ -52,7 +50,6 @@ private:
     Q_PRIVATE_SLOT(d, void slotTooltipValidityChanged(bool))
     Q_PRIVATE_SLOT(d, void slotTooltipDetailsChanged(bool))
     Q_PRIVATE_SLOT(d, void slotTooltipOwnerChanged(bool))
-    Q_PRIVATE_SLOT(d, void slotUseTagsChanged(bool))
 };
 
 }
