@@ -1,6 +1,4 @@
-/* -*- mode: c++; c-basic-offset:4 -*-
-    crypto/createchecksumscontroller.cpp
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB
 
@@ -171,7 +169,7 @@ private:
 #ifndef QT_NO_PROGRESSDIALOG
         if (progressDialog) {
             progressDialog->setValue(progressDialog->maximum());
-            progressDialog->close();
+            progressDialog->accept();
         }
 #endif // QT_NO_PROGRESSDIALOG
         auto const dlg = new ResultDialog(created, errors);
@@ -304,7 +302,7 @@ void CreateChecksumsController::start()
 
 void CreateChecksumsController::cancel()
 {
-    qCDebug(KLEOPATRA_LOG);
+    qCDebug(KLEOPATRA_LOG) << this << __func__;
     const QMutexLocker locker(&d->mutex);
     d->canceled = true;
 }
