@@ -16,7 +16,6 @@
 #include "commands/lookupcertificatescommand.h"
 #include "crypto/decryptverifytask.h"
 #include "view/htmllabel.h"
-#include "view/urllabel.h"
 
 #include <Libkleo/ApplicationPaletteWatcher>
 #include <Libkleo/AuditLogEntry>
@@ -85,7 +84,7 @@ public:
     QList<QPointer<QWidget>> m_mainStylesheetWidgets;
     QList<ResultItemData> m_itemStylesheetWidgets;
     const std::shared_ptr<const Task::Result> m_result;
-    UrlLabel *m_auditLogLabel = nullptr;
+    QPushButton *m_auditLogButton = nullptr;
     QPushButton *m_closeButton = nullptr;
     QPushButton *m_showButton = nullptr;
     bool m_importCanceled = false;
@@ -134,19 +133,28 @@ void ResultItemWidget::Private::addIgnoreMDCButton(QBoxLayout *lay)
     lay->addWidget(btn);
 }
 
-static QUrl auditlog_url_template()
-{
-    QUrl url(QStringLiteral("kleoresultitem://showauditlog"));
-    return url;
-}
-
 void ResultItemWidget::Private::updateShowDetailsLabel()
 {
-    const auto auditLogUrl = m_result->auditLog().asUrl(auditlog_url_template());
+    m_auditLogButton->setVisible(false);
+    if (const int code = m_result->auditLog().error().code()) {
+        if (code == GPG_ERR_NOT_IMPLEMENTED) {
+            qCDebug(KLEOPATRA_LOG) << "not showing link (not implemented)";
+        } else if (code == GPG_ERR_NO_DATA) {
+            qCDebug(KLEOPATRA_LOG) << "not showing link (not available)";
+        } else {
+            qCDebug(KLEOPATRA_LOG) << "Error Retrieving Audit Log:" << Formatting::errorAsString(m_result->auditLog().error());
+        }
+        return;
+    }
+
+    if (m_result->auditLog().text().isEmpty()) {
+        return;
+    }
+
     const auto auditLogLinkText = m_result->hasError() ? i18n("Diagnostics") //
                                                        : i18nc("The Audit Log is a detailed error log from the gnupg backend", "Show Audit Log");
-    m_auditLogLabel->setUrl(auditLogUrl, auditLogLinkText);
-    m_auditLogLabel->setVisible(!auditLogUrl.isEmpty());
+    m_auditLogButton->setText(auditLogLinkText);
+    m_auditLogButton->setVisible(true);
 }
 
 void ResultItemWidget::Private::updateStyleSheets()
@@ -206,12 +214,12 @@ ResultItemWidget::Private::Private(const std::shared_ptr<const Task::Result> &re
 
     addIgnoreMDCButton(actionLayout);
 
-    m_auditLogLabel = new UrlLabel;
-    connect(m_auditLogLabel, &QLabel::linkActivated, q, [this](const auto &link) {
-        slotLinkActivated(link);
+    m_auditLogButton = new QPushButton;
+    connect(m_auditLogButton, &QPushButton::clicked, q, [this]() {
+        AuditLogViewer::showAuditLog(q->parentWidget(), m_result->auditLog());
     });
-    actionLayout->addWidget(m_auditLogLabel);
-    m_mainStylesheetWidgets.push_back(m_auditLogLabel);
+    actionLayout->addWidget(m_auditLogButton);
+    m_mainStylesheetWidgets.push_back(m_auditLogButton);
 
     for (const auto &detail : m_result.get()->detailsList()) {
         auto frame = new QFrame;
@@ -250,6 +258,7 @@ ResultItemWidget::Private::Private(const std::shared_ptr<const Task::Result> &re
 
     m_closeButton = new QPushButton;
     KGuiItem::assign(m_closeButton, KStandardGuiItem::close());
+    m_closeButton->setToolTip(i18nc("@info:tooltip", "Close message"));
     m_closeButton->setFixedSize(m_closeButton->sizeHint());
     connect(m_closeButton, &QAbstractButton::clicked, q, &ResultItemWidget::closeButtonClicked);
     actionLayout->addWidget(m_closeButton);
@@ -315,11 +324,6 @@ void ResultItemWidget::Private::slotLinkActivated(const QString &link)
 
     const QUrl url(link);
 
-    if (url.host() == QLatin1StringView("showauditlog")) {
-        q->showAuditLog();
-        return;
-    }
-
     if (url.scheme() == QStringLiteral("certificate")) {
         auto cmd = new Kleo::Commands::LookupCertificatesCommand(url.path(), nullptr);
         connect(cmd, &Kleo::Commands::LookupCertificatesCommand::canceled, q, [this]() {
@@ -335,9 +339,4 @@ void ResultItemWidget::Private::slotLinkActivated(const QString &link)
     qCWarning(KLEOPATRA_LOG) << "Unexpected link scheme: " << link;
 }
 
-void ResultItemWidget::showAuditLog()
-{
-    AuditLogViewer::showAuditLog(parentWidget(), d->m_result->auditLog());
-}
-
 #include "moc_resultitemwidget.cpp"
