@@ -8,10 +8,8 @@
 
 #pragma once
 
-#include <QString>
 #include <Libkleo/GnuPG>
+#include <QString>
 
 #define WATCHGNUPGBINARY QStringLiteral("watchgnupg")
-#define WATCHGNUPGSOCKET QString( Kleo::gnupgHomeDirectory() + QLatin1String("/log-socket") )
-
-
+#define WATCHGNUPGSOCKET QString(Kleo::gnupgHomeDirectory() + QLatin1StringView("/log-socket"))
