@@ -1,6 +1,4 @@
-/* -*- mode: c++; c-basic-offset:4 -*-
-    uiserver/decryptverifycommandfilesbase.cpp
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2007 Klarälvdalens Datakonsult AB
 
@@ -10,11 +8,9 @@
 #include <config-kleopatra.h>
 
 #include "decryptverifycommandfilesbase.h"
-#include "fileoperationspreferences.h"
 
 #include <crypto/decryptverifytask.h>
 
-#include "crypto/autodecryptverifyfilescontroller.h"
 #include "crypto/decryptverifyfilescontroller.h"
 
 #include <utils/input.h>
@@ -94,12 +90,7 @@ int DecryptVerifyCommandFilesBase::doStart()
 {
     d->checkForErrors();
 
-    FileOperationsPreferences prefs;
-    if (prefs.autoDecryptVerify()) {
-        d->controller.reset(new AutoDecryptVerifyFilesController());
-    } else {
-        d->controller.reset(new DecryptVerifyFilesController(shared_from_this()));
-    }
+    d->controller.reset(new DecryptVerifyFilesController());
 
     d->controller->setOperation(operation());
     d->controller->setFiles(fileNames());
